<?php
/**
 * Admin Coupon Stores Metaboxes.
 *
 * @package Clipper\Admin\Metaboxes\Stores
 * @author  AppThemes
 * @since   Clipper 1.6
 */


add_action( APP_TAX_STORE . '_edit_form_fields', 'clpr_edit_stores', 10, 2 );
add_action( 'edited_' . APP_TAX_STORE, 'clpr_save_stores', 10, 2 );
add_filter( 'media_upload_tabs', 'clpr_stores_media_remove_from_url_tab' );


/**
 * Displays the custom url meta field for the stores taxonomy.
 *
 * @param object $tag
 * @param string $taxonomy
 *
 * @return void
 */
function clpr_edit_stores( $tag, $taxonomy ) {
	$the_store_url = clpr_get_store_meta( $tag->term_id, 'clpr_store_url', true );
	$the_store_aff_url = clpr_get_store_meta( $tag->term_id, 'clpr_store_aff_url', true );
	$the_store_active = clpr_get_store_meta( $tag->term_id, 'clpr_store_active', true );
	$store_featured = clpr_get_store_meta( $tag->term_id, 'clpr_store_featured', true );
	$the_store_aff_url_clicks = clpr_get_store_meta( $tag->term_id, 'clpr_aff_url_clicks', true );
	// $clpr_store_image_url = clpr_get_store_meta( $tag->term_id, 'clpr_store_image_url', true );
	$clpr_store_image_id = clpr_get_store_meta( $tag->term_id, 'clpr_store_image_id', true );
	$clpr_store_image_preview = clpr_get_store_image_url( $tag->term_id, 'term_id', 75 );
?>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_url"><?php _e( 'Store URL', APP_TD ); ?></label></th>
		<td>
			<input type="url" name="clpr_store_url" id="clpr_store_url" value="<?php echo esc_url( $the_store_url ); ?>" placeholder="http://" /><br />
			<p class="description"><?php _e( 'The URL for the store (i.e. http://www.website.com)', APP_TD ); ?></p>
		</td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_aff_url"><?php _e( 'Destination URL', APP_TD ); ?></label></th>
		<td>
			<input type="url" name="clpr_store_aff_url" id="clpr_store_aff_url" value="<?php echo esc_url( $the_store_aff_url ); ?>" placeholder="http://" /><br />
			<p class="description"><?php _e( 'The affiliate URL for the store (i.e. http://www.website.com/?affid=12345)', APP_TD ); ?></p>
		</td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_aff_url_cloaked"><?php _e( 'Display URL', APP_TD ); ?></label></th>
		<td><?php echo clpr_get_store_out_url( $tag ); ?></td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_aff_url_clicks"><?php _e( 'Clicks', APP_TD ); ?></label></th>
		<td><?php echo esc_html( $the_store_aff_url_clicks ); ?></td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_active"><?php _e( 'Store Active', APP_TD ); ?></label></th>
		<td>
			<select class="postform" id="clpr_store_active" name="clpr_store_active" style="min-width:125px;">
				<option value="yes" <?php selected( $the_store_active, 'yes' ); ?>><?php _e( 'Yes', APP_TD ); ?></option>
				<option value="no" <?php selected( $the_store_active, 'no' ); ?>><?php _e( 'No', APP_TD ); ?></option>
			</select>
		</td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_featured"><?php _e( 'Store Featured', APP_TD ); ?></label></th>
		<td>
			<input type="checkbox" value="1" name="clpr_store_featured" <?php checked( $store_featured ); ?>> <span class="description"><?php _e( 'Yes', APP_TD ); ?></span>
		</td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_url"><?php _e( 'Store Screenshot', APP_TD ); ?></label></th>
		<td>
			<span class="thumb-wrap">
				<a href="<?php echo esc_url( $the_store_url ); ?>" target="_blank"><img class="store-thumb" src="<?php echo esc_url( clpr_get_store_image_url( $tag->term_id, 'term_id', 250 ) ); ?>" alt="" /></a>
			</span>
		</td>
	</tr>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="clpr_store_image_id"><?php _e( 'Store Image', APP_TD ); ?></label></th>
		<td>
			<div id="stores_image" style="float:left; margin-right:15px;"><img src="<?php echo esc_url( $clpr_store_image_preview ); ?>" /></div>
			<div style="line-height:75px;">
				<input type="hidden" name="clpr_store_image_id" id="clpr_store_image_id" value="<?php echo esc_attr( $clpr_store_image_id ); ?>" />
				<button type="submit" class="button" id="button_add_image" rel="clpr_store_image_url"><?php _e( 'Add Image', APP_TD ); ?></button>
				<button type="submit" class="button" id="button_remove_image"><?php _e( 'Remove Image', APP_TD ); ?></button>
			</div>
			<div class="clear"></div>
			<p class="description"><?php _e( 'Choose custom image for the store.', APP_TD ); ?></p>
			<p class="description"><?php _e( 'Leave blank if you want use image generated by store URL.', APP_TD ); ?></p>
		</td>
	</tr>
	<script type="text/javascript">
	//<![CDATA[
	jQuery(document).ready(function() {

		var formfield;

		if ( ! jQuery('#clpr_store_image_id').val() ) {
			jQuery('#button_remove_image').hide();
		} else {
			jQuery('#button_add_image').hide();
		}

		jQuery( document ).on('click', '#button_add_image', function() {
			formfield = jQuery(this).attr('rel');
			tb_show('', 'media-upload.php?post_id=0&amp;type=image&amp;taxonomy=<?php echo APP_TAX_STORE; ?>&amp;TB_iframe=true');
			return false;
		});

		jQuery( document ).on('click', '#button_remove_image', function() {
			jQuery('#stores_image img').attr('src', '<?php echo esc_js( appthemes_locate_template_uri( 'images/clpr_default.jpg' ) ); ?>');
			jQuery('#clpr_store_image_id').val('');
			jQuery('#button_remove_image').hide();
			jQuery('#button_add_image').show();
			return false;
		});

		window.original_send_to_editor = window.send_to_editor;

		window.send_to_editor = function(html) {
			if ( formfield ) {
				var imageClass = jQuery('img', html).attr('class');
				var imageID = parseInt(/wp-image-(\d+)/.exec(imageClass)[1], 10);
				var imageURL = jQuery('img', html).attr('src');

				jQuery('input[name=clpr_store_image_id]').val(imageID);
				jQuery('#stores_image img').attr('src', imageURL);
				jQuery('#button_remove_image').show();
				jQuery('#button_add_image').hide();
				tb_remove();
				formfield = null;
			} else {
				window.original_send_to_editor(html);
			}
		}

	});
	//]]>
	</script>

<?php
}


/**
 * Saves the store url custom meta field.
 *
 * @param int $term_id
 * @param int $tt_id
 *
 * @return void
 */
function clpr_save_stores( $term_id, $tt_id ) {
	if ( ! $term_id ) {
		return;
	}

	if ( isset( $_POST['clpr_store_image_id'] ) && is_numeric( $_POST['clpr_store_image_id'] ) ) {
		clpr_update_store_meta( $term_id, 'clpr_store_image_id', $_POST['clpr_store_image_id'] );
	}

	if ( isset( $_POST['clpr_store_url'] ) && $url = wp_http_validate_url( $_POST['clpr_store_url'] ) ) {
		clpr_update_store_meta( $term_id, 'clpr_store_url', $url );
	}

	if ( isset( $_POST['clpr_store_aff_url'] ) && $url = wp_http_validate_url( $_POST['clpr_store_aff_url'] ) ) {
		clpr_update_store_meta( $term_id, 'clpr_store_aff_url', $url );
	}

	if ( isset( $_POST['clpr_store_active'] ) ) {
		clpr_update_store_meta( $term_id, 'clpr_store_active', $_POST['clpr_store_active'] );
	}

	if ( isset( $_POST['clpr_store_featured'] ) ) {
		clpr_update_store_meta( $term_id, 'clpr_store_featured', $_POST['clpr_store_featured'] );
	} else {
		clpr_delete_store_meta( $term_id, 'clpr_store_featured' );
	}

	delete_transient( 'clpr_hidden_stores_ids' );
	delete_transient( 'clpr_featured_stores_ids' );
}


/**
 * Removes 'From URL' tab in media uploader, need local image for stores.
 *
 * @param array $tabs
 *
 * @return array
 */
function clpr_stores_media_remove_from_url_tab( $tabs ) {

	if ( isset( $_GET['taxonomy'] ) && $_GET['taxonomy'] == APP_TAX_STORE ) {
		unset( $tabs['type_url'] );
	}

	return $tabs;
}


/**
 * Admin HTML Store Description.
 * @since 1.6
 */
class CLPR_Store_Term_Description extends CLPR_Term_Description {

	/**
	 * Setups editor.
	 *
	 * @return void
	 */
	public function __construct() {
		parent::__construct( APP_TAX_STORE );
	}

}

